# Simple graphics with Pimoroni Galactic Unicorn - GU Bounce.py
#  === Bouncing blob - with and without trail ===
#       Tony Goodhew 6th November 2022
# @TonyGo2@mastodon.social @tonygo09066653

from galactic import GalacticUnicorn
from picographics import PicoGraphics, DISPLAY_GALACTIC_UNICORN
import time
from machine import Pin, I2C

# create a PicoGraphics framebuffer to draw into
graphics = PicoGraphics(display=DISPLAY_GALACTIC_UNICORN)

# create our GalacticUnicorn object
gu = GalacticUnicorn()
#Define some colours
BLACK = graphics.create_pen(0, 0, 0)
RED =  graphics.create_pen(255, 0, 0)
YELLOW = graphics.create_pen(255, 255, 0)
GREEN = graphics.create_pen(0, 255, 0)
CYAN =  graphics.create_pen(0, 255, 255)
BLUE =  graphics.create_pen(0, 0, 255)
MAGENTA =  graphics.create_pen(255, 0, 255)
WHITE =  graphics.create_pen(200, 200, 200)
GREY =  graphics.create_pen(100, 100, 100)
DRKGRY =  graphics.create_pen(20, 20, 20)

colours =[RED,YELLOW,GREEN,CYAN,BLUE,MAGENTA] # Blob colours

graphics.set_pen(GREEN)         # Title screen
msg = "Bounce"
graphics.text(msg, 10, 1, scale=1)
gu.update(graphics)
time.sleep(3)

graphics.set_pen(BLACK)
graphics.clear()
gu.update(graphics)

dx = 1 # Initial conditions
dy = 1
x = 13
y = 5
cp = 2                            # Colour pointer
delay = 0.05

for count in range(1400):
    # Delete old blob
    if (count < 100) or (count > 800):
        graphics.set_pen(BLACK)  # No trail  
    else:        
        graphics.set_pen(DRKGRY) # Leave trail
    
    graphics.circle(x,y,1)
    # Update position
    x = x + dx
    y = y + dy
    if (x == 51) or (x == 1):     # Hit end?
        dx = dx * -1              # Reverse horizontal direction
        cp = (cp + 1) % 6         # Change colour
    if (y == 9) or (y == 1):      # Hit top or bottom?
        dy = dy * -1              # Reverse vertical direction
        cp = (cp + 1) % 6         # Change colour
    graphics.set_pen(colours[cp]) # Adjust blob colour
    graphics.circle(x,y,1)        # Draw blob
    gu.update(graphics)           # show new position
    time.sleep(delay)
    
    if count == 200:              # Gradually speed things up
        delay = 0.04
    elif count == 400:
        delay = 0.03
    elif count == 500:
        delay = 0.02
    elif count == 600:
        delay = 0.01
    elif count == 800:
        graphics.set_pen(BLACK)   # Remove trails - once
        graphics.clear()
        gu.update(graphics)
        delay = 0                 # Flat out!

#================================================================================
# Tidy up
graphics.set_pen(GREEN)
msg = "Done"
graphics.text(msg, 20, 1, scale=1)
gu.update(graphics)
time.sleep(4)

graphics.set_pen(BLACK)
graphics.clear()
gu.update(graphics)



